%ifarch %{arm}
%define enable_tests	0
%else
%define enable_tests	0
%endif

Name:		engauge-digitizer
Version:	9.8
Release:	%mkrel 1
Summary:	Convert graphs or map files into numbers
Group:		Sciences/Other
License:	GPLv2+
URL:		https://github.com/markummitchell/engauge-digitizer
Source0:	https://github.com/markummitchell/engauge-digitizer/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	%{name}.appdata.xml
Source2:	%{name}.svg
Source3:	%{name}-with-name.svg
Patch0:		%{name}-9.1-fix_test_script.patch
Patch1:		%{name}-9.4-fix_translations_path.patch
### Main building
BuildRequires:	desktop-file-utils
BuildRequires:	qttools5
BuildRequires:	qttools5-assistant
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(poppler-qt5)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(log4cpp)

### Doxygen for documentation
BuildRequires:	doxygen
BuildRequires:	texlive-collection-basic

%if %{enable_tests}
### Xvfb is needed to run a virtual X server used by tests
BuildRequires:	x11-server-xvfb
BuildRequires:	pkgconfig(Qt5Test)
%endif

%description
Engauge 9 is rewritten with Qt5.
This digitizing software converts an image file showing a graph or map, into
numbers.
The image file can come from a scanner, digital camera or screen-shot.
The numbers can be read on the screen, and written or copied to a spreadsheet.
The process starts with an image file containing a graph or map.
The final result is digitized data that can be used by other tools such as
Gnumeric.

New features already added to Engauge:

* Older Engauge files (before version 6) can be loaded
* Undo/redo of all operations means recovering from mistakes and experimenting
  with options is painless
* Wizard provides an interactive tutorial to explain the basic steps
* Wizard creates a checklist guide to interactively leads user through steps
  from file import to file export
* Cubic spline interpolation between points gives more accurate curves with
  fewer points
* Axes Checker briefly highlights the axes when they are defined or modified,
  to reveal entry mistakes
* Graph coordinates can be specified as date and time value, or as degrees,
  minutes and seconds
* All settings dialogs are resizable so they can be enlarged as necessary to
  display more information
* Import by drag-and-drop
* Replacement of Qt3 (which is at its end of life) by Qt5
* Much better zooming, with a fill mode that automatically zooms in on image
  features, and rezooms when the application window is resized
* Color picking straight from the original image
* Uploadable error report generated when a programming error is encountered,
  for identifying problems and improving user support
* Test suite for regression testing minimizes code breakage
  as new features are added
* Multiple coordinate systems in the same image can be digitized in advanced mode
* Axes with only one known coordinate (floating axes) can be digitized in
  advanced mode
* File import by pasting

%package	samples
Summary:	Sample files for %{name}
Group:		Documentation
BuildArch:	noarch

%description	samples
This package contains several sample image files that may be imported into
Engauge Digitizer (http://digitizer.sourceforge.net).

These files are listed below, with comments:

* corners.png - Graph that lots of corners that would be painful
  to digitize manually
* gridlines.gif - Graph with gridlines that are easily removed by Engauge
* gridlines_log.gif - Another graph with gridlines that are easily
  removed by Engauge
* gridlines_log.src - Creates gridlines_log.gif in gnuplot using 'load'
  command (not an image!)
* inverse.jpg - Image of y/x function
* inverse.png - Same as inverse.jpg but in png format
* linlog.jpg - Graph with linear/logarithmic coordinates
* linlog.png - Same as linlog.jpg but in png format
* loglin.png - Graph with logarithmic/linear coordinates
* loglog.png - Graph with logarithmic/logarithmic coordinates
* normdist.jpg - Graph of normal distribution
* normdist.png - Same as normdist.jpg but in png format
* pointmatch.jpg - Graph with fuzzy points for playing with Point Match
  feature of Engauge
* pointplot.bmp - Graph with points that are easily captured by Point Match
  feature of Engauge, if the Discretize settings are set to "Intensity 90
  to 99" for the triangles, and "Intensity 10 to 50" for the diamonds
* polarcircles.jpg - Polar plot for experimenting. No coordinates are
  displayed, so not very useful
* polarplot.jpg - Polar plot with cardioid pattern
* polarplot.png - Same as polarplot.jpg but in png format
* testcase.jpg - Simple graph that serves as an excellent starting point
  for the new user
* testcase.png - Same as testcase.jpg but in png format
* testcoords.jpg - Advanced graph used by developers to check the affine
  transformations in Engauge
* testcoords.sxd - Open Office document used to create testcoords.jpg
  (not an image!)
* usgs.png - Fictional map loosely based on U.S. Geological Survey
  topographic maps

%package	doc
Summary:	HTML documentation of %{name}
Group:		Documentation
BuildArch:	noarch

%description	doc
HTML documentation of %{name}.

%prep
%setup -q

%if %{enable_tests}
### optimization flags for compilers
%patch0 -p1
sed -e 's|RPM_OPT_FLAGS|"%{optflags}"|g' -i src/build_and_run_all_cli_tests
%endif

%patch1 -p1

### Remove default -O1 optimization
sed -e 's|-O1||g' -i engauge.pro

### Active support to jpeg2000 and support to pdf
sed -e 's|CONFIG += qt warn_on thread|CONFIG += qt warn_on thread jpeg2000 pdf|g' -i engauge.pro

### Remove spurious executable permissions
for i in `find src -type f \( -name "*.cpp" -o -name "*.h" \)`; do
chmod a-x $i
done

%build
export OPENJPEG_INCLUDE=%{_includedir}/openjpeg-2.1
export OPENJPEG_LIB=%{_libdir}
export POPPLER_INCLUDE=%{_includedir}/poppler/qt5
export POPPLER_LIB=%{_libdir}
export ENGAUGE_RELEASE=1

### Build engauge
%{_qt5_bindir}/lrelease engauge.pro
%qmake_qt5 engauge.pro DEFINES+=HELPDIR=%{_docdir}/%{name}/help
%make_build

### Build HELP files
pushd help
%{_qt5_bindir}/qcollectiongenerator engauge.qhcp -o engauge.qhc
mv engauge.qch ../bin/documentation
mv engauge.qhc ../bin/documentation
rm -f build
popd

### Build HTML/Latex documentation files
pushd src
doxygen
popd

%install
### Install binary
mkdir -p %{buildroot}%{_bindir}
install -p -m 755 bin/engauge %{buildroot}%{_bindir}

### Install sample files
mkdir -p %{buildroot}%{_datadir}/%{name}/samples
pushd samples
install -p -m 644 *.gif *.jp* *.p* *.bmp *.x* %{buildroot}%{_datadir}/%{name}/samples
popd

### Install img files
mkdir -p %{buildroot}%{_datadir}/%{name}/img
install -p -m 644 src/img/* %{buildroot}%{_datadir}/%{name}/img

### Install appdata file
mkdir -p %{buildroot}%{_datadir}/appdata
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/appdata

### Install icons svg
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -p -m 644 %{SOURCE2} %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -p -m 644 %{SOURCE3} %{buildroot}%{_iconsdir}/hicolor/scalable/apps

### Install translation files
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
install -p -m 0644 translations/*.qm %{buildroot}%{_datadir}/%{name}/translations/

### Install .desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=Engauge Digitizer
Type=Application
Comment=Extracts data points from images of graphs
Comment[fr]=Extraits des points de données à partir d'images de graphiques
TryExec=engauge
Exec=engauge %%F
MimeType=text/plain;
Categories=Education;Science;DataVisualization;
Icon=%{name}-with-name
Keywords=analog;digital;converter;
EOF

%check
### Tests
%if %{enable_tests}
pushd src
xvfb-run -s "-screen 0 640x480x24" -a  sh -x ./build_and_run_all_cli_tests
%endif

%files
%doc README.md help/
%doc bin/documentation/engauge.qhc bin/documentation/engauge.qch
%license LICENSE
%{_bindir}/engauge
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/scalable/apps/%{name}*.svg
%exclude %{_datadir}/%{name}/samples

%files samples
%doc samples/README
%license LICENSE
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/samples

%files doc
%doc README.md doc/doxygen/html
%license LICENSE


%changelog
* Fri Dec 23 2016 daviddavid <daviddavid> 9.8-1.mga6
+ Revision: 1076664
- new version: 9.8

* Fri Dec 02 2016 daviddavid <daviddavid> 9.7-1.mga6
+ Revision: 1071629
- new version: 9.7

* Tue Nov 22 2016 daviddavid <daviddavid> 9.6-1.mga6
+ Revision: 1068773
- new version: 9.6

* Fri Oct 14 2016 daviddavid <daviddavid> 9.5-1.mga6
+ Revision: 1060744
- new version: 9.5

* Sun Oct 02 2016 daviddavid <daviddavid> 9.4-3.mga6
+ Revision: 1058108
- new version: 9.4
- package all translation files
- add BR texlive-collection-basic for build doc

* Wed Sep 07 2016 daviddavid <daviddavid> 9.3-1.mga6
+ Revision: 1050394
- new version: 9.3

* Sat Aug 13 2016 luigiwalser <luigiwalser> 9.1-2.mga6
+ Revision: 1046232
- test rebuild for poppler

* Thu Aug 11 2016 daviddavid <daviddavid> 9.1-1.mga6
+ Revision: 1045554
- new version: 9.1
- fix jpeg2000 support
- enable support to pdf with poppler-qt5
- rename and rediff fix_test_script patch
- improve desktop file and appdata file

* Sat Apr 09 2016 daviddavid <daviddavid> 7.2-1.mga6
+ Revision: 999816
- new version: 7.2

* Thu Mar 24 2016 daviddavid <daviddavid> 7.1-1.mga6
+ Revision: 995174
- new version: 7.1

  + blino <blino>
    - re-enable tests on ARM, it should not fail and the failure did not look ARM-specific

* Mon Mar 07 2016 daviddavid <daviddavid> 7.0-2.mga6
+ Revision: 986929
- disable tests on arm

* Mon Mar 07 2016 daviddavid <daviddavid> 7.0-1.mga6
+ Revision: 986919
- new version: 7.0
- rename and rediff fix_test_script patch
- update of appdata file
- update of description

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Dec 02 2015 daviddavid <daviddavid> 6.2-1.mga6
+ Revision: 907765
- imported package engauge-digitizer (based on Fedora)

